IndexManager

Struct IndexManager 

pub struct IndexManager { /* private fields */ }

Implementations

Source

impl IndexManager

pub fn new() -> Self

pub fn add_index(&mut self, definition: IndexDefinition)

pub fn get_indexed_fields(&self, entity: &str) -> Option<&Vec<String>>

pub fn update_indexes( &self, batch: &mut BatchWriter, entity: &Entity, old_entity: Option<&Entity>, )

pub fn remove_indexes(&self, batch: &mut BatchWriter, entity: &Entity)

pub fn lookup_by_field( &self, storage: &Storage, entity: &str, field: &str, value: &[u8], ) -> Result<Vec<String>>

Errors

Returns an error if the storage prefix scan fails.

pub fn is_field_indexed(&self, entity: &str, field: &str) -> bool

pub fn persist_index( &self, batch: &mut BatchWriter, definition: &IndexDefinition, ) -> Result<()>

Errors

Returns an error if serialization fails.

pub fn load_indexes(&mut self, storage: &Storage) -> Result<()>

Errors

Returns an error if reading or deserializing index definitions fails.

pub fn lookup_by_range( &self, storage: &Storage, entity: &str, field: &str, lower: Option<(&[u8], bool)>, upper: Option<(&[u8], bool)>, ) -> Result<Vec<String>>

Errors

Returns an error if the storage range scan fails.